# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['copernicusmarine',
 'copernicusmarine.aioretry',
 'copernicusmarine.catalogue_parser',
 'copernicusmarine.command_line_interface',
 'copernicusmarine.core_functions',
 'copernicusmarine.download_functions',
 'copernicusmarine.python_interface']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.8.5',
 'boto3>=1.25',
 'cachier>=2.2.1',
 'click>=8.0.4',
 'dask>=2022',
 'lxml>=4.9.0',
 'motuclient>=1.8.4',
 'nest-asyncio>=1.5.8',
 'netCDF4>=1.5.4',
 'pydap>=3.2.2',
 'pystac>=1.8.3',
 'requests>=2.27.1',
 'semver>=3.0.2',
 'setuptools>=68.2.2',
 'tqdm>=4.65.0',
 'xarray>=2023.4.0',
 'zarr>=2.13.3']

entry_points = \
{'console_scripts': ['copernicusmarine = '
                     'copernicusmarine.command_line_interface.copernicus_marine:command_line_interface']}

setup_kwargs = {
    'name': 'copernicusmarine',
    'version': '1.0.10',
    'description': '',
    'long_description': '\n<h1 align="center">Copernicus Marine Service toolbox (CLI & Python)</h1>\n<div align="center">\n  <a href="https://pypi.org/project/copernicusmarine/"><img src="https://img.shields.io/pypi/v/copernicusmarine.svg?style=flat-square" alt="PyPI" /></a>\n  <a href="https://pypi.org/project/copernicusmarine/"><img src="https://img.shields.io/pypi/pyversions/copernicusmarine.svg?style=flat-square" alt="PyPI Supported Versions" /></a>\n  <a href="https://pypi.org/project/copernicusmarine/"><img src="https://img.shields.io/badge/platform-windows | linux | macos-lightgrey?style=flat-square" alt="Supported Platforms" /></a>\n  <a href="https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12"><img src="https://img.shields.io/badge/licence-EUPL-lightblue?style=flat-square" alt="Licence" /></a>\n</div>\n\n![Copernicus Marine Service and Mercator Ocean international logos](https://www.mercator-ocean.eu/wp-content/uploads/2022/05/Cartouche_CMEMS_poisson_MOi.png)\n\n## Features\nThe `copernicusmarine` offers capabilities through both **Command Line Interface (CLI)** and **Python API**:\n- **Metadata Information**: List and retrieve metadata information on all variables, datasets, products, and their associated documentation.\n- **Subset Datasets**: Subset datasets to extract only the parts of interest, in preferred format, such as Analysis-Ready Cloud-Optimized (ARCO) Zarr or NetCDF file format.\n- **Advanced Filters**: Apply simple or advanced filters to get multiple files, in original formats like NetCDF/GeoTIFF, via direct Marine Data Store connections.\n- **No Quotas**: Enjoy no quotas, neither on volume size nor bandwidth.\n\n## Installation\nFor installation, multiple options are available depending on your setup:\n\n### Conda|Mamba\n\nA conda package is available and has been uploaded to the conda-forge channel.\n\nHere is the main web page of it: [https://anaconda.org/conda-forge/copernicusmarine](https://anaconda.org/conda-forge/copernicusmarine)\n\nYou can install it using conda though the conda-forge channel with the following command: `conda install copernicusmarine -c conda-forge`\n\n### Docker\n\nA docker image is also available here: [https://hub.docker.com/r/copernicusmarine/copernicusmarine](https://hub.docker.com/r/copernicusmarine/copernicusmarine)\n\nHere is a basic command to run it: `docker run -it --rm copernicusmarine/copernicusmarine --version`\n\n### Pip\nOtherwise, if you already have an environment (safer to clone it), the package can be installed using the `pip` command:\n```bash\npython -m pip install copernicusmarine\n```\n\nAnd to **upgrade the package** to the newest available version, run:\n```bash\npython -m pip install copernicusmarine --upgrade\n```\n\n## User Guide\nFor more comprehensive details on how to use the `copernicusmarine`, please refer to our [Help Center](https://help.marine.copernicus.eu/en/collections/4060068-copernicus-marine-toolbox). It ensures a smooth migration for existing users of legacy services such as MOTU, OPeNDAP, and FTP.\n\n### General configuration\n\n#### Cache Usage\n\nCachier library is used for caching part of the requests (as describe result or login). By default, the cache will be located in the home folder. If you need to change the location of the cache, you can set the environment variable `COPERNICUSMARINE_CACHE_DIRECTORY` to point to the desired directory.\n\n#### Disable SSL\n\nA global SSL context is used when making HTTP calls using the `copernicusmarine` toolbox. For some reason, it can lead to unexpected behavior depending on your network configuration. You can set the `COPERNICUSMARINE_DISABLE_SSL_CONTEXT` environmnent variable to any value to globally disable the usage of SSL in the client (e.g. `COPERNICUSMARINE_DISABLE_SSL_CONTEXT=True`).\n\n## Command Line Interface (CLI)\n\n### The `--help` option\nTo discover commands and their available options, consider appending `--help` on any command line.\n\nExample:\n```bash\ncopernicusmarine --help\n```\nReturns:\n```bash\nUsage: copernicusmarine [OPTIONS] COMMAND [ARGS]...\n\nOptions:\n  -V, --version  Show the version and exit.\n  --help         Show this message and exit.\n\nCommands:\n  describe  Print Copernicus Marine catalog as JSON\n  login     This command check the copernicusmarine credentials provided...\n  get       Download originally produced data files\n  subset    Downloads subsets of datasets as NetCDF files or Zarr stores\n```\n\n### Command `describe`\nRetrieve metadata information about all products/datasets and display as JSON output:\n```bash\ncopernicusmarine describe --include-datasets\n```\n\nThe JSON output can also be saved like follows:\n```bash\ncopernicusmarine describe --include-datasets > all_datasets_copernicusmarine.json\n```\n\n### Command `login`\nCreate a single configuration file `.copernicusmarine-credentials` allowing to access all Marine Data Store data services. By default, it saves file in user\'s home directory.\n\nExample:\n```bash\n> copernicusmarine login\nusername : johndoe\npassword :\nINFO - Configuration files stored in /Users/foo/.copernicusmarine\n```\n\nIf `.copernicusmarine-credentials` already exists, the user is asked for confirmation to overwrite (`--overwrite`/`--overwrite-configuration-file`).\n\nYou can use the `--skip-if-user-logged-in` option to skip the configuration file overwrite if the user is already logged in.\n\n#### Access points migration and evolution\n\nIf you already have a configuration for current services (e.g. `~/motuclient/motuclient-python.ini`, `~/.netrc` or `~/_netrc`) in your home directory, it will automatically be taken into account with commands `get` and `subset` without the need for running the `login` command.\nIf the configuration files are already available in another directory, when running commands `subset` or `get`, you can use the `--credentials-file` option to point to the file.\n\n### Command `subset`\nRemotely subset a dataset, based on variable names, geographical and temporal parameters.\n\nExample:\n```bash\ncopernicusmarine subset --dataset-id cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --variable thetao --variable so --start-datetime 2021-01-01 --end-datetime 2021-01-03 --minimum-longitude 0.0 --maximum-longitude 0.1 --minimum-latitude 28.0 --maximum-latitude 28.1\n```\nReturns:\n```bash\nINFO     - Download through S3\n<xarray.Dataset>\nDimensions:    (depth: 50, latitude: 2, longitude: 1, time: 1)\nCoordinates:\n  * depth      (depth) float32 0.5058 1.556 2.668 ... 5.292e+03 5.698e+03\n  * latitude   (latitude) float32 28.0 28.08\n  * longitude  (longitude) float32 0.08333\n  * time       (time) datetime64[ns] 2021-01-01\nData variables:\n    thetao     (time, depth, latitude, longitude) float32 dask.array<chunksize=(1, 50, 2, 1), meta=np.ndarray>\n    so         (time, depth, latitude, longitude) float32 dask.array<chunksize=(1, 50, 2, 1), meta=np.ndarray>\nAttributes: (12/19)\n    Conventions:    CF-1.0\n    bulletin_date:  2022-11-01\n    ...             ...\n    title:          CMEMS IBI REANALYSIS: YEARLY PHYSICAL PRODUCTS\nDo you want to proceed with download? [Y/n]:\n```\n\nBy default, after the display of the summary of the dataset subset, a download confirmation is asked. To skip this user\'s action, call option `--force-download`.\n\n#### Note about longitude range\nOptions `--minimum-longitude` and `--maximum-longitude` work as follows:\n- If the result of the substraction ( `--maximum-longitude` minus `--minimum-longitude` ) is superior or equal to 360, then return the full dataset.\n- If the requested longitude range:\n  - **does not cross** the antemeridian, then return the dataset between range -180° and 180°.\n  - **does cross** the antemeridian, then return the dataset between range 0° and 360°.\n\nNote that you can request any longitudes you want. A modulus is applied to bring the result between -180° and 360°. For example, if you request [530°, 560°], the result dataset will be in [170°, 200°].\n\n#### Access point migration and evolution\nThe copernicus marine toolbox will download the data in the most efficient way according to your request:\n- if the target dataset **is available** in ARCO version, then files are downloaded in a fresh new folder in the current working directory.\n- if the target dataset **is not yet available** in ARCO version, then a file is downloaded in the current working directory.\n> **_NOTE:_**  The filename will be with the following format `dataset_id-longitude_range-latitude_range-depth_range-date_range.[nc|zarr]`\n\nHowever, the output directory and filename can be specified using `-o`/`--output-directory` and `-f`/`--output-filename` respectively. If the later ends with `.nc`, it will be written as a NetCDF file.\n\nYou can force the use of a specific data access service with option `--service`.\n\n#### Note about netcdf-compression-enabled and --netcdf-compression-enabled options\nWhen subseting data, if you decide to write your data as a NetCDF file (which is the default behavior), then you can provide the extra option "--netcdf-compression-enabled". The downloaded file will be lighter but it will take you more time to write it (because of the compression task). If you don\'t provide it, the task will be faster, but the file heavier.\nFinally, if you decide to write your data in ZARR format (.zarr extension), then the original compression that is used in the Marine Data Store will be apply, which mean that the download task will be fast AND the file compressed. In that case, you cannot use the "netcdf-compression-enabled" as it has no sense.\n\nHere is the default options added to xarray in the background when using the option: {\'zlib\': True, \'complevel\': 1, \'contiguous\': False, \'shuffle\': True}\n\nIn addition to this option, you can also provide the `--netcdf-compression-enabled` option and customize the NetCDF compression level between 0 (no compression) and 9.\n\n### Command `get`\nDownload the dataset file(s) as originally produced, based on the datasetID or the path to files.\n\nExample:\n```bash\ncopernicusmarine get --dataset-url ftp://my.cmems-du.eu/Core/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --service original-files\n```\nReturns:\n```bash\nINFO     - You forced selection of service: original-files\nINFO     - Downloading using service original-files...\nINFO     - You requested the download of the following files:\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_19930101_19931231_R20221101_RE01.nc - 8.83 MB\n[... truncated for brevity..]\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20120101_20121231_R20221101_RE01.nc - 8.62 MB\nPrinted 20 out of 29 files\n\nTotal size of the download: 252.94 MB\n\nDo you want to proceed with download? [Y/n]\n```\n\nYou can force the use of a specific data access service with option `--service`.\n\nBy default:\n\n- after the header displays a summary of the request, a download confirmation is asked. To skip this user\'s action, add option `--force-download`.\n- files are downloaded to the current directory applying the original folder structure. To avoid this behavior, add `--no-directories` and specify a destination with the `--output-directory` option.\n\nOption `--show-outputnames` displays the full paths of the output files, if required.\n\nOption `--create-file-list` only creates a file containing the names of the targeted files instead of downloading them.\nYou have to input a file name: `--create-file-list my_files.txt`. The format needs to be `.txt` or `.csv`:\n\n- if the user inputs a file name that ends in `.txt` then this file contains only the full s3 path to the targeted files and is compatible with the `--file-list` option. See example of `my_files.txt`:\n\n```\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/1993/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_19930101_19930131_R20201201_RE01.nc\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/1993/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_19930201_19930228_R20201201_RE01.nc\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/1993/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_19930301_19930331_R20201201_RE01.nc\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/1993/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_19930401_19930430_R20201201_RE01.nc\n```\n\n- if the user inputs a file name that ends in `.csv` then this file contains the following columns: filename, size (in B), last_modified_datetime, etag. See example of `my_files.csv`:\n\n```\nfilename,size,last_modified_datetime,etag\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/1993/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_19930101_19930131_R20201201_RE01.nc,12623497,2023-11-12 23:46:45.009000+00:00,"247c5bb6013ddf71ebe707f7eab810de"\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/1993/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_19930201_19930228_R20201201_RE01.nc,12608349,2023-11-12 23:46:45.122000+00:00,"5ed77080ddce9500223610952bcc61a2"\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/1993/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_19930301_19930331_R20201201_RE01.nc,12497110,2023-11-12 23:46:45.178000+00:00,"c49e3d575688946a2d36341b4d3d8a80"\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/1993/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_19930401_19930430_R20201201_RE01.nc,12481867,2023-11-12 23:46:45.336000+00:00,"bf0b937af7bc8b43e35694323ddce099"\n```\nIf specified, no other action will be performed.\n\n#### Note about sync option\n\nOption `--sync` allows to download original files only if not exist and not up to date. The toolbox checks the destination folder against the source folder. It can be combined with filters. Note that if set with `--overwrite-output-data`, the latter will be ignored.\nThe logic is largely inspired from [s5mp package sync command](https://github.com/peak/s5cmd#sync)\nOption `--sync-delete` will work as `--sync` with the added fonctionnality that it deletes any local file that has not been found on the remote server. Note that the files found on the server are also filtered. Hence, a file present locally might be deleted even if it is on the server because,  for example, the executed `get` command contains a filter that excludes this specific file.\nLimitations:\n- is not compatible with `--no-directories`.\n- Version needs to be set when using sync (with `--force-dataset-version` flag)\n- As for now, the sync functionality is not available for datasets with several parts (like INSITU or static datasets for example).\n\n#### Note about filtering options\nOption `--filter` allows to specify a Unix shell-style wildcard pattern (see [fnmatch — Unix filename pattern matching](https://docs.python.org/3/library/fnmatch.html)) and select specific files:\n```bash\ncopernicusmarine get --dataset-id cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --filter "*01yav_200[0-2]*"\n```\nReturns:\n```bash\nINFO     - Downloading using service files...\nINFO     - You requested the download of the following files:\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20000101_20001231_R20221101_RE01.nc - 8.93 MB\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20010101_20011231_R20221101_RE01.nc - 8.91 MB\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20020101_20021231_R20221101_RE01.nc - 8.75 MB\n\nTotal size of the download: 26.59 MB\nDo you want to proceed with download? [Y/n]:\n```\n\nOption `--regex` allows to specify a regular expression for more advanced files selection:\n```bash\ncopernicusmarine get -i cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --regex ".*01yav_20(00|01|02).*.nc"\n```\nReturns:\n```bash\nINFO     - Downloading using service files...\nINFO     - You requested the download of the following files:\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20000101_20001231_R20221101_RE01.nc - 8.93 MB\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20010101_20011231_R20221101_RE01.nc - 8.91 MB\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20020101_20021231_R20221101_RE01.nc - 8.75 MB\n\nTotal size of the download: 26.59 MB\nDo you want to proceed with download? [Y/n]:\n```\n\nOption `--file-list` allows to specify a list of files for more advanced files selection:\n\nAn example `file_list.txt` would look like this:\n```txt\nCMEMS_v5r1_IBI_PHY_MY_NL_01yav_20000101_20001231_R20221101_RE01.nc\nCMEMS_v5r1_IBI_PHY_MY_NL_01yav_20010101_20011231_R20221101_RE01.nc\nCMEMS_v5r1_IBI_PHY_MY_NL_01yav_20020101_20021231_R20221101_RE01.nc\n```\n> **_NOTE:_**  This option is compatible with the file generated by the `--create-file-list` option if you generated a ".txt" file.\n\nThen the following command:\n```bash\ncopernicusmarine get -i cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --file-list file_list.txt\n```\nReturns:\n```bash\nINFO     - Downloading using service files...\nINFO     - You requested the download of the following files:\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20000101_20001231_R20221101_RE01.nc - 8.93 MB\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20010101_20011231_R20221101_RE01.nc - 8.91 MB\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20020101_20021231_R20221101_RE01.nc - 8.75 MB\n\nTotal size of the download: 26.59 MB\nDo you want to proceed with download? [Y/n]:\n```\n\nAlso, there is a specific command `--index-part` to retrieve the index files of INSITU datasets (for index files example see [this link on Copernicus Marine Service](https://data.marine.copernicus.eu/product/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/files?subdataset=cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311--ext--history&path=INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034%2Fcmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311%2F)). Note that in the future, we plan to have the index files for those datasets, directly available through the filter, regex and/or file-list options.\n\nThen the following command:\n```\ncopernicusmarine get --dataset-id cmems_obs-ins_blk_phybgcwav_mynrt_na_irr --index-parts\n```\n\nReturns:\n```\nINFO - 2024-03-13T08:08:12Z - Dataset version was not specified, the latest one was selected: "202311"\nINFO - 2024-03-13T08:08:12Z - Dataset part was not specified, the first one was selected: "history"\nINFO - 2024-03-13T08:08:12Z - You forced selection of service: original-files\nINFO - 2024-03-13T08:08:12Z - Downloading using service original-files...\nINFO - 2024-03-13T08:08:13Z - You requested the download of the following files:\ns3://mdl-native-08/native/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311/index_history.txt - 244.61 kB - 2023-11-30T17:01:25Z\ns3://mdl-native-08/native/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311/index_latest.txt - 572.09 kB - 2024-03-13T07:21:00Z\ns3://mdl-native-08/native/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311/index_monthly.txt - 1.51 MB - 2024-03-05T18:09:43Z\ns3://mdl-native-08/native/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311/index_platform.txt - 209.11 kB - 2024-03-13T07:21:00Z\n\nTotal size of the download: 2.53 MB\n\n\nDo you want to proceed with download? [Y/n]:\n```\n### Shared options\nBoth `subset` and `get` commands provide these options:\n\n#### Option `--overwrite-output-data`\n\nWhen specified, the existing files will be overwritten.\nOtherwise, if the files already exist on destination, new ones with a unique index will be created once the download has been accepted (or once `--force-download` is provided).\n\n#### Option `--request-file`\n\nThis option allows to specify CLI options but in a provided JSON file, useful for batch processing.\n\n- Template for `subset` data request:\n```json\n{\n\t"dataset_id": "cmems_mod_glo_phy-thetao_anfc_0.083deg_P1D-m",\n\t"start_datetime": "2022-04-11",\n\t"end_datetime": "2023-08-11",\n\t"minimum_longitude": -182.79,\n\t"maximum_longitude": -179.69,\n\t"minimum_latitude": -40,\n\t"maximum_latitude": -36,\n\t"minimum_depth": 0,\n\t"maximum_depth": 0,\n\t"variables": ["thetao"],\n\t"output_directory": "./data/",\n\t"output_filename": "temperature_small_pacific_2022208-202308.zarr",\n\t"force_download": false\n}\n```\n\nExample:\n```bash\ncopernicusmarine subset --request-file template_subset_data_request.json\n```\n\n- Template for `get` data request:\n```json\n{\n    "dataset_id": "cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m",\n    "filter": "*01yav_200[0-2]*",\n    "force_download": false,\n    "service": "files",\n    "log_level": "INFO",\n    "no_directories": false,\n    "no_metadata_cache": false,\n    "output_directory": "./data/",\n    "overwrite_output_data": false,\n    "overwrite_metadata_cache": false,\n    "show_outputnames": true\n}\n```\n\nExample:\n```bash\ncopernicusmarine get --request-file template_get_data_request.json\n```\n\n#### Option `--credentials-file`\nYou can use the `--credentials-file` option to point to a credentials file. The file can be either `.copernicusmarine-credentials`, `motuclient-python.ini`, `.netrc` or `_netrc`.\n\n\n#### Option `--dataset-version`\nYou can use the `--dataset-version` option to fetch a specific dataset version.\n\n#### Option `--dataset-part`\nYou can use the `--dataset-part` option to fecth a specific part for the chosen dataset version.\n\n\n## Python package (API)\nThe `copernicusmarine` exposes a Python interface to allow you to [call commands as functions](https://marine.copernicus.eu/python-interface).\n\n## Documentation\nSee the [Help Center](https://help.marine.copernicus.eu/en/collections/4060068-copernicus-marine-toolbox). A detailed standalone API documentation is under construction and will come at a later stage.\n\n## Contribution\nWe welcome contributions from the community to enhance this package. If you find any issues or have suggestions for improvements, please check out our [Report Template](https://help.marine.copernicus.eu/en/articles/8218546-how-to-report-a-bug-or-suggest-new-features).\n\n## Future improvements & Roadmap\n- [ ] Make available the currently not managed Analysis-Ready Cloud-Optimized (ARCO) versions of Ocean Monitoring Indicator (OMI), in situ and static datasets.\n- [ ] Allow to specify the compression level when downloading your subset as NetCDF file.\n- [ ] Allow to subset variables using their `standard_name(s)` and not only their `name(s)`.\n\nTo keep up to date with the most recent and planned advancements, including revisions, corrections, and feature requests generated from users\' feedback, please refer to our [Roadmap](https://help.marine.copernicus.eu/en/articles/8218641-what-are-the-next-milestones).\n\n## Join the community\nGet in touch!\n- Create your [Copernicus Marine Account](https://data.marine.copernicus.eu/register)\n- [Log in](https://data.marine.copernicus.eu/login?redirect=%2Fproducts) and chat with us (bottom right corner of [Copernicus Marine Service](https://marine.copernicus.eu/))\n- Join our [training workshops](https://marine.copernicus.eu/services/user-learning-services)\n- Network y/our [Copernicus Stories](https://twitter.com/cmems_eu)\n- Watch [our videos](https://www.youtube.com/channel/UC71ceOVy7WtVC7F04BKoEew)\n\n## Licence\nLicensed under the [EUPL](https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12)\n',
    'author': 'Copernicus Marine User Support',
    'author_email': 'servicedesk.cmems@mercator-ocean.eu',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<3.13',
}


setup(**setup_kwargs)
